@@ -6,21 +6,19 @@ local decode = require("json.decode")
 local encode = require("json.encode")
 local util = require("json.util")
 
-local is_52 = _VERSION == "Lua 5.2"
-
 local _G = _G
 
-if is_52 then
-	_ENV = nil
-end
+_ENV = nil
 
 local json = {
+	_VERSION = "1.3",
+	_DESCRIPTION = "LuaJSON : customizable JSON decoder/encoder",
+	_COPYRIGHT = "Copyright (c) 2007-2012 Thomas Harning Jr. <harningt@gmail.com>",
 	decode = decode,
 	encode = encode,
 	util = util
 }
 
-if not is_52 then
-	_G.json = json
-end
+_G.json = json
+
 return json
