@@ -7,12 +7,7 @@ local assert = assert
 local jsonutil = require("json.util")
 local huge = require("math").huge
 
-local is_52 = _VERSION == "Lua 5.2"
-local _G = _G
-
-if is_52 then
-	_ENV = nil
-end
+_ENV = nil
 
 local defaultOptions = {
 	nan = true,
@@ -60,10 +55,4 @@ local number = {
 	getEncoder = getEncoder
 }
 
-if not is_52 then
-	_G.json = _G.json or {}
-	_G.json.encode = _G.json.encode or {}
-	_G.json.encode.number = number
-end
-
 return number
